@@ -1,5 +1,5 @@
 #!/usr/bin/env node
-require('yargs')
+require('yargs/yargs')(process.argv.slice(2))
   .commandDir('cmds')
   .demandCommand()
   .help()
