@@ -1,6 +1,6 @@
 #!/usr/bin/env node
 
-var argv = require('yargs')
+var argv = require('yargs/yargs')(process.argv.slice(2))
     .default({ x : 10, y : 10 })
     .argv
 ;
