@@ -1,6 +1,6 @@
 #!/usr/bin/env node
 
-var argv = require('yargs')
+var argv = require('yargs/yargs')(process.argv.slice(2))
     .usage('Usage: $0 -x [num] -y [num]')
     .demand(['x','y'])
     .argv;
