@@ -1,6 +1,6 @@
 var yargs = require('../index');
 
-var argv = yargs
+var argv = require('yargs/yargs')(process.argv.slice(2))
   .usage('This is my awesome program\n\nUsage: $0 [options]')
   .help('help').alias('help', 'h')
   .version('version', '1.0.1').alias('version', 'V')
